%	Analytical results for the overflow probabilities by Norros, Husler&Piterbarg, and our approximation in the paper:
% 	Performance evaluation and service rate provisioning for a queue with fractional Brownian input.

function prob = FBm_prob(H,sigma2,m,q,type,const)
%   FBm_prob return Pr(Q>q) with input parameter H, sigma, m, q
%   H:      Hurst parameter
%   sigma2: sigma_1^2
%   m:      net mean input
%   q:      q in Pr(Q>q)
%   type:   1:Norros 2:Husler&Piterbarg 3:new approximation
% 	const:  constant C for the asymptotics by Husler and Piterbarg

if type==1  %Norros
    x = q;
    prob = exp(-(x.^(2-2*H) * H^(-2*H) * (1-H)^(2*H-2) * (abs(m))^(2*H) / (sigma2 * 2)));
elseif type==2  %Husler and Piterbarg
    x = q;
    prob = const*x^(2*H-3+1/H) * exp(-(x.^(2-2*H) * H^(-2*H) * (1-H)^(2*H-2) * (abs(m))^(2*H) / (sigma2 * 2)));
else	% new approximation
    f = @(x)x.^(-2+1/H).*exp(-(x.^(2-2*H) * H^(-2*H) * (1-H)^(2*H-2) * (abs(m))^(2*H) / (sigma2 * 2)));
    c = 1/quadgk(f,0,inf);
    fp = @(x)x.^(-2+1/H).*exp(-(x.^(2-2*H) * H^(-2*H) * (1-H)^(2*H-2) * (abs(m))^(2*H) / (sigma2 * 2)))*c;
    prob = quadgk(fp,q,inf);
end