/*
 * The codes generate the fGn sequences by Hosking's methods
 * in the paper: Performance evaluation and service rate provisioning for a queue with fractional Brownian input,
 * based on the codes by Ton Dieker from
 * http://www2.isye.gatech.edu/~adieker3/fbm.html .
 */

#include <stdio.h>
#include "hosking.h"

void genFBM(long n, double H, double L, int cum, char *out){
	/* function that writes a fractional Brownian motion or fractional	   */
	/* Gaussian noise sample into a file.						           */
	/* Input:  n      determines the sample size N by N=2^(*n)             */
	/*         H      the Hurst parameter of the trace                     */
	/*         L      the sample is generated on [0,L]                     */
	/*         cum    = 0: fractional Gaussian noise is produced           */
	/*                = 1: fractional Brownian motion is produced          */
	/*         *out	  name of the output file							   */
	int i;
	double *output;
	long seed1, seed2, NUM;
	FILE *out1, *out2;
	
	out1 = fopen(out,"w");
	seed1 = 1;
	seed2 = 2;
	NUM = (long)pow(2.0,n);
	output = (double *) calloc(NUM, sizeof(double));

	hosking(&n, &H, &L, &cum, &seed1, &seed2, output);
	for(i=0;i<NUM;i++){
		fprintf(out1,"%lf\t", output[i]);
	}
	fclose(out1);
}

/*
 * This is an example of generating the fGn numbers.
 */
void main(){
	char output[100];
	int cum;
	int n;
	double H, L, var;
	printf("n: ");
	scanf("%d", &n);
	printf("Var: ");
	scanf("%lf", &var);
	printf("H: ");
	scanf("%lf", &H);

	sprintf(output, "z:/n%dv%.2fH%.2f.txt", n, var, H);
	printf("Saving to %s ...", output);

	L = pow(2.0,(double)n)*var;
	cum = 0;
	genFBM(n,H,L,cum,output);
	
}